# Data Pipelines in AutoTrader

AutoTrader supports custom data pipelines with the [DataStream](utils-datastream) class utility. 
This is particularly useful when you plan to trade multiple contracts on the same underlying product,
where you want a single trading bot to trade multiple contracts. This is possible with a custom 
DataStream.





